@@ -23,6 +23,10 @@
 
 #include <stdlib.h>
 
+#include <iostream>
+
+#include <boost/format.hpp>
+
 #include <glibmm/thread.h>
 #include <glibmm/i18n.h>
 #include <glibmm/optionentry.h>
@@ -85,16 +89,14 @@ namespace gnote {
     {
     }
 
-    if(cmd_line.needs_execute()) {
-      cmd_line.execute();
-    }
+    m_is_panel_applet = cmd_line.use_panel_applet();
 
     m_icon_theme = Gtk::IconTheme::get_default();
     m_icon_theme->append_search_path(DATADIR"/icons");
     m_icon_theme->append_search_path(DATADIR"/gnote/icons");
 
     std::string note_path = get_note_path(cmd_line.note_path());
-    m_manager = new NoteManager(note_path);
+    m_manager = new NoteManager(note_path, sigc::mem_fun(*this, &Gnote::start_note_created));
     m_keybinder = new XKeybinder();
 
     // TODO
@@ -112,10 +114,13 @@ namespace gnote {
       (*iter)->initialize();
     }
 
-    if(cmd_line.use_panel_applet()) {
+    if(cmd_line.needs_execute()) {
+      cmd_line.execute();
+    }
+
+    if(m_is_panel_applet) {
       DBG_OUT("starting applet");
       s_tray_icon_showing = true;
-      m_is_panel_applet = true;
 
       am["CloseWindowAction"]->set_visible(true);
       am["QuitGNoteAction"]->set_visible(false);
@@ -137,6 +142,15 @@ namespace gnote {
     return 0;
   }
 
+
+  void Gnote::start_note_created(const Note::Ptr & start_note)
+  {
+    DBG_OUT("we will show the start note: %d", !is_panel_applet());
+    if(!is_panel_applet()) {
+      start_note->get_window()->show();
+    }
+  }
+
   std::string Gnote::get_note_path(const std::string & override_path)
   {
     std::string note_path;
@@ -342,9 +356,9 @@ namespace gnote {
   GnoteCommandLine::GnoteCommandLine()
     : Glib::OptionGroup("Gnote", _("A note taking application"))
     , m_new_note(false)
-    , m_open_search(false)
     , m_open_start_here(false)
     , m_use_panel(false)
+    , m_show_version(false)
   {
     Glib::OptionEntry entry;
     entry.set_long_name("panel-applet");
@@ -355,22 +369,62 @@ namespace gnote {
     entry2.set_long_name("note-path");
     entry2.set_description(_("Specify the path of the directory containing the notes."));
     add_entry(entry2, m_note_path);
+
+    Glib::OptionEntry entry3;
+    entry3.set_long_name("search");
+    entry3.set_description(_("Open the search all notes window with the search text."));
+    add_entry(entry3, m_search);
+
+    Glib::OptionEntry entry4;
+    entry4.set_long_name("version");
+    entry4.set_description(_("Print version information."));
+    add_entry(entry4, m_show_version);
   }
 
   int GnoteCommandLine::execute()
+
   {
-    // TODO
+    bool quit = false;
+#ifndef ENABLE_DBUS
+      // as long as we don't have the DBus support.
+    if(!m_search.empty()) {
+      NoteRecentChanges * recent_changes
+        = NoteRecentChanges::get_instance(
+          Gnote::obj().default_note_manager());
+
+      recent_changes->set_search_text(m_search);
+
+      recent_changes->present ();
+    }
+#endif
+    if(m_show_version) {
+      print_version();
+      quit = true;
+    }
+
+    if(quit) {
+      exit(0);
+    }
     return 0;
   }
 
+  void GnoteCommandLine::print_version()
+  {
+    Glib::ustring version = str(boost::format(_("Version %1%"))
+                                % VERSION);
+    std::cerr << version << std::endl;
+  }
+
+
   bool GnoteCommandLine::needs_execute() const
   {
     return m_new_note ||
       !m_open_note_name.empty() ||
       !m_open_note_uri.empty() ||
-      m_open_search ||
+      !m_search.empty() ||
       m_open_start_here ||
-      !m_open_external_note_path.empty();
+      !m_open_external_note_path.empty() ||
+      m_show_version;
   }
 
 
