@@ -194,7 +194,11 @@ namespace gnote {
   NoteWindow::~NoteWindow()
   {
     delete m_global_keys;
+    m_global_keys = NULL;
     delete m_mark_set_timeout;
+    m_mark_set_timeout = NULL;
+    // make sure editor is NULL. See bug 586084
+    m_editor = NULL;
     Preferences::obj().remove_notify(m_gconf_notify);
   }
 
@@ -293,7 +297,9 @@ namespace gnote {
   void NoteWindow::on_selection_mark_set(const Gtk::TextIter&, const Glib::RefPtr<Gtk::TextMark>&)
   {
     // FIXME: Process in a timeout due to GTK+ bug #172050.
-    m_mark_set_timeout->reset(0);
+    if(m_mark_set_timeout) {
+      m_mark_set_timeout->reset(0);
+    }
   }
 
   void NoteWindow::update_link_button_sensitivity()
@@ -455,7 +461,8 @@ namespace gnote {
       m_delete_button->set_sensitive(false);
     }
     tb->insert(*manage(new Gtk::SeparatorToolItem()), -1);
-    
+
+#if 0    // Disable because of bug 585610
     Gtk::ImageMenuItem *item =
       manage(new Gtk::ImageMenuItem (_("Synchronize Notes")));
     item->set_image(*manage(new Gtk::Image(Gtk::Stock::CONVERT, Gtk::ICON_SIZE_MENU)));
@@ -463,6 +470,7 @@ namespace gnote {
       sigc::mem_fun(*this, &NoteWindow::sync_item_selected));
     item->show();
     m_plugin_menu->add(*item);
+#endif
 
     tb->show_all();
     return tb;
@@ -556,7 +564,9 @@ namespace gnote {
   {
     // Reposition the current focus back to the editor so the
     // cursor will be ready for typing.
-    m_editor->grab_focus();
+    if(m_editor) {
+      m_editor->grab_focus();
+    }
   }
 
   //
