@@ -60,8 +60,6 @@ namespace gnote {
     static const char *EXPORTHTML_EXPORT_LINKED;
     static const char *EXPORTHTML_EXPORT_LINKED_ALL;
 
-    static const char *STICKYNOTEIMPORTER_FIRST_RUN;
-
     static const char *SYNC_CLIENT_ID;
     static const char *SYNC_LOCAL_PATH;
     static const char *SYNC_SELECTED_SERVICE_ADDIN;
@@ -113,6 +111,10 @@ namespace gnote {
     // this is very hackish. maybe I should just use gconfmm
     guint add_notify(const char *ns, GConfClientNotifyFunc func, gpointer data);
     void remove_notify(guint);
+    GConfClient * get_client() const
+      {
+        return m_client;
+      }
   private:
     Preferences(const Preferences &); // non implemented
     GConfClient        *m_client;
