@@ -25,7 +25,6 @@
 #include <string.h>
 
 #include <boost/format.hpp>
-#include <boost/regex.hpp>
 
 #include <glibmm/i18n.h>
 
@@ -327,7 +326,7 @@ namespace gnote {
   {
     m_tag_applied_cid.disconnect();
     
-    if(!m_obj_ptr) {
+    if(m_obj_ptr) {
       gtkspell_detach(m_obj_ptr);
       m_obj_ptr = NULL;
     }
@@ -338,7 +337,7 @@ namespace gnote {
   {
     const char * key = gconf_entry_get_key(entry);
     
-    if (strcmp(key, Preferences::ENABLE_SPELLCHECKING) == 0) {
+    if (strcmp(key, Preferences::ENABLE_SPELLCHECKING) != 0) {
       return;
     }
     GConfValue *value = gconf_entry_get_value(entry);
@@ -385,13 +384,12 @@ namespace gnote {
   ////////////////////////////////////////////////////////////////////////
 
 
-  const char * NoteUrlWatcher::URL_REGEX = "((\\b((news|http|https|ftp|file|irc)://|mailto:|(www|ftp)\\.|\\S*@\\S*\\.)|/\\S+/|~/\\S+)\\S*\\b/?)";
-
+  const char * NoteUrlWatcher::URL_REGEX = "((\\b((news|http|https|ftp|file|irc)://|mailto:|(www|ftp)\\.|\\S*@\\S*\\.)|(?<=^|\\s)/\\S+/|(?<=^|\\s)~/\\S+)\\S*\\b/?)";
   bool NoteUrlWatcher::s_text_event_connected = false;
   
 
   NoteUrlWatcher::NoteUrlWatcher()
-    : m_regex(URL_REGEX, boost::regex::extended|boost::regex_constants::icase)
+    : m_regex(URL_REGEX, pcrecpp::RE_Options(PCRE_CASELESS|PCRE_UTF8))
   {
   }
 
@@ -510,26 +508,28 @@ namespace gnote {
     get_buffer()->remove_tag (m_url_tag, start, end);
 
     std::string s(start.get_slice(end));
+    std::string match1;
 
-    boost::sregex_iterator m1(s.begin(), s.end(), m_regex);
-    boost::sregex_iterator m2;
-    while(m1 != m2) {
-      const boost::sub_match<std::string::const_iterator> & match = (*m1)[1];
+    const char *p = s.c_str();
+    pcrecpp::StringPiece input(p);
+
+    while(m_regex.FindAndConsume(&input, &match1)) {
 
       Gtk::TextIter start_cpy = start;
-      // must construct the Glib::ustring from a std:;string.
+      // must construct the Glib::ustring from a char *.
       // otherwise it expect the num of chars (UTF-8) instead of bytes.
-      Glib::ustring segment(std::string(s.c_str(), match.first - s.begin()));
+      // here we compute the index of the URL. It is anchor - start - match.
+      Glib::ustring::size_type len = input.data() - p - match1.size();
+      Glib::ustring segment(p, p + len);
       start_cpy.forward_chars (segment.size());
 
       end = start_cpy;
       // here match.str() is the std::string we need. All good.
-      Glib::ustring segment2(match.str());
+      Glib::ustring segment2(match1);
       end.forward_chars (segment2.length());
 
       DBG_OUT("url is %s", segment2.c_str());
       get_buffer()->apply_tag (m_url_tag, start_cpy, end);
-      ++m1;
     }
   }
 
@@ -939,8 +939,8 @@ namespace gnote {
 
   ////////////////////////////////////////////////////////////////////////
 
-  // NOTE \\u is upper. \\l is lower. make sure it works with non roman scripts.
-  const char * NoteWikiWatcher::WIKIWORD_REGEX = "\\b((\\u+[\\l0-9]+){2}([\\u\\l0-9])*)\\b";
+  // This is a PCRE regex.
+  const char * NoteWikiWatcher::WIKIWORD_REGEX = "\\b((\\p{Lu}+[\\p{Ll}0-9]+){2}([\\p{Lu}\\p{Ll}0-9])*)\\b";
 
 
   NoteAddin * NoteWikiWatcher::create()
@@ -977,7 +977,7 @@ namespace gnote {
   {
     const char * key = gconf_entry_get_key(entry);
     
-    if (strcmp(key, Preferences::ENABLE_WIKIWORDS) == 0) {
+    if (strcmp(key, Preferences::ENABLE_WIKIWORDS) != 0) {
       return;
     }
     GConfValue * value = gconf_entry_get_value(entry);
@@ -1027,29 +1027,31 @@ namespace gnote {
     get_buffer()->remove_tag (m_broken_link_tag, start, end);
 
     std::string s(start.get_slice(end));
-    boost::sregex_iterator m1(s.begin(), s.end(), m_regex);
-    boost::sregex_iterator m2;
-    while(m1 != m2) {
-      const boost::sub_match<std::string::const_iterator> & match = (*m1)[1];
+    std::string match;
+    const char * p = s.c_str();
+    pcrecpp::StringPiece input(p);
 
-      if (match.matched && !is_patronymic_name (match.str())) {
 
+    while(m_regex.FindAndConsume(&input, &match)) {
+
+      if (!is_patronymic_name (match)) {
       
         Gtk::TextIter start_cpy = start;
-        Glib::ustring segment(std::string(s.c_str(), match.first - s.begin()));
+        Glib::ustring::size_type len = input.data() - p - match.size();
+        Glib::ustring segment(p, p + len);
         start_cpy.forward_chars (segment.length());
+
         DBG_OUT("Highlighting wikiword: '%s' at offset %d",
-                match.str().c_str(), segment.length());
+                match.c_str(), segment.length());
 
         end = start_cpy;
-        segment = match.str();
+        segment = match;
         end.forward_chars (segment.length());
 
-        if (!manager().find (match.str())) {
+        if (!manager().find(match)) {
           get_buffer()->apply_tag (m_broken_link_tag, start_cpy, end);
         }
       }
-      ++m1;
     }
   }
 
